summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPhilip Withnall <philip@tecnocode.co.uk>2023-01-11 14:58:31 +0000
committerPhilip Withnall <philip@tecnocode.co.uk>2023-01-11 14:58:31 +0000
commite9fc91550fa080eed7d4decdd1ab13eec75e0514 (patch)
tree0f96ebdf1f446edf3b6e87f2539ee2affa7cdec2
parent19554979939bb3bcc0dd3e24cf7e898cb8450a61 (diff)
parentfc70f2c057f3f28d35233b756ec786103d4e769f (diff)
downloadglib-e9fc91550fa080eed7d4decdd1ab13eec75e0514.tar.gz
Merge branch 'badcel/revert-update-closure-annotations' into 'main'
Revert "Rename user data parameters to user_data" Closes #2827 See merge request GNOME/glib!3111
-rw-r--r--gio/giotypes.h40
-rw-r--r--glib/ghook.c6
-rw-r--r--glib/ghook.h6
-rw-r--r--glib/giochannel.c2
-rw-r--r--glib/giochannel.h2
-rw-r--r--glib/gnode.c4
-rw-r--r--glib/gnode.h4
-rw-r--r--glib/goption.h18
-rw-r--r--glib/gsequence.c2
-rw-r--r--glib/gsequence.h2
-rw-r--r--glib/gspawn.h4
-rw-r--r--glib/gthread.c2
-rw-r--r--glib/gthread.h2
-rw-r--r--glib/gtree.c2
-rw-r--r--glib/gtree.h6
-rw-r--r--glib/gtypes.h8
-rw-r--r--gobject/gclosure.h4
-rw-r--r--gobject/gsignal.h8
18 files changed, 61 insertions, 61 deletions
diff --git a/glib/ghook.c b/glib/ghook.c
index 6ef89733d..3db220187 100644
--- a/glib/ghook.c
+++ b/glib/ghook.c
@@ -584,7 +584,7 @@ g_hook_list_invoke_check (GHookList *hook_list,
/**
* GHookCheckMarshaller:
* @hook: a #GHook
- * @user_data: user data
+ * @marshal_data: user data
*
* Defines the type of function used by g_hook_list_marshal_check().
*
@@ -636,7 +636,7 @@ g_hook_list_marshal_check (GHookList *hook_list,
/**
* GHookMarshaller:
* @hook: a #GHook
- * @user_data: user data
+ * @marshal_data: user data
*
* Defines the type of function used by g_hook_list_marshal().
*/
@@ -793,7 +793,7 @@ g_hook_get (GHookList *hook_list,
/**
* GHookFindFunc:
* @hook: a #GHook
- * @user_data: user data passed to g_hook_find_func()
+ * @data: user data passed to g_hook_find_func()
*
* Defines the type of the function passed to g_hook_find().
*
diff --git a/glib/ghook.h b/glib/ghook.h
index 203bc364e..1bd858219 100644
--- a/glib/ghook.h
+++ b/glib/ghook.h
@@ -43,11 +43,11 @@ typedef struct _GHookList GHookList;
typedef gint (*GHookCompareFunc) (GHook *new_hook,
GHook *sibling);
typedef gboolean (*GHookFindFunc) (GHook *hook,
- gpointer user_data);
+ gpointer data);
typedef void (*GHookMarshaller) (GHook *hook,
- gpointer user_data);
+ gpointer marshal_data);
typedef gboolean (*GHookCheckMarshaller) (GHook *hook,
- gpointer user_data);
+ gpointer marshal_data);
typedef void (*GHookFunc) (gpointer data);
typedef gboolean (*GHookCheckFunc) (gpointer data);
typedef void (*GHookFinalizeFunc) (GHookList *hook_list,
diff --git a/glib/giochannel.c b/glib/giochannel.c
index a16891f4f..6eb6ec717 100644
--- a/glib/giochannel.c
+++ b/glib/giochannel.c
@@ -679,7 +679,7 @@ g_io_add_watch_full (GIOChannel *channel,
* GIOFunc:
* @source: the #GIOChannel event source
* @condition: the condition which has been satisfied
- * @user_data: user data set in g_io_add_watch() or g_io_add_watch_full()
+ * @data: user data set in g_io_add_watch() or g_io_add_watch_full()
*
* Specifies the type of function passed to g_io_add_watch() or
* g_io_add_watch_full(), which is called when the requested condition
diff --git a/glib/giochannel.h b/glib/giochannel.h
index dee3d7d05..913019cd4 100644
--- a/glib/giochannel.h
+++ b/glib/giochannel.h
@@ -130,7 +130,7 @@ struct _GIOChannel
typedef gboolean (*GIOFunc) (GIOChannel *source,
GIOCondition condition,
- gpointer user_data);
+ gpointer data);
struct _GIOFuncs
{
GIOStatus (*io_read) (GIOChannel *channel,
diff --git a/glib/gnode.c b/glib/gnode.c
index a9988ebd8..b9a68c2f6 100644
--- a/glib/gnode.c
+++ b/glib/gnode.c
@@ -868,7 +868,7 @@ g_node_depth_traverse_level (GNode *node,
/**
* GNodeTraverseFunc:
* @node: a #GNode.
- * @user_data: user data passed to g_node_traverse().
+ * @data: user data passed to g_node_traverse().
*
* Specifies the type of function passed to g_node_traverse(). The
* function is called with each of the nodes visited, together with the
@@ -1245,7 +1245,7 @@ g_node_last_sibling (GNode *node)
/**
* GNodeForeachFunc:
* @node: a #GNode.
- * @user_data: user data passed to g_node_children_foreach().
+ * @data: user data passed to g_node_children_foreach().
*
* Specifies the type of function passed to g_node_children_foreach().
* The function is called with each child node, together with the user
diff --git a/glib/gnode.h b/glib/gnode.h
index b3f89f02a..94ab99621 100644
--- a/glib/gnode.h
+++ b/glib/gnode.h
@@ -58,9 +58,9 @@ typedef enum
} GTraverseType;
typedef gboolean (*GNodeTraverseFunc) (GNode *node,
- gpointer user_data);
+ gpointer data);
typedef void (*GNodeForeachFunc) (GNode *node,
- gpointer user_data);
+ gpointer data);
/* N-way tree implementation
*/
diff --git a/glib/goption.h b/glib/goption.h
index 6d7de3ae5..739311f6e 100644
--- a/glib/goption.h
+++ b/glib/goption.h
@@ -138,8 +138,8 @@ typedef enum
* single dash followed by a single letter (for a short name) or two dashes
* followed by a long option name.
* @value: The value to be parsed.
- * @user_data: User data added to the #GOptionGroup containing the option when
- * it was created with g_option_group_new()
+ * @data: User data added to the #GOptionGroup containing the option when it
+ * was created with g_option_group_new()
* @error: A return location for errors. The error code %G_OPTION_ERROR_FAILED
* is intended to be used for errors in #GOptionArgFunc callbacks.
*
@@ -151,15 +151,15 @@ typedef enum
*/
typedef gboolean (*GOptionArgFunc) (const gchar *option_name,
const gchar *value,
- gpointer user_data,
+ gpointer data,
GError **error);
/**
* GOptionParseFunc:
* @context: The active #GOptionContext
* @group: The group to which the function belongs
- * @user_data: User data added to the #GOptionGroup containing the option when
- * it was created with g_option_group_new()
+ * @data: User data added to the #GOptionGroup containing the option when it
+ * was created with g_option_group_new()
* @error: A return location for error details
*
* The type of function that can be called before and after parsing.
@@ -169,22 +169,22 @@ typedef gboolean (*GOptionArgFunc) (const gchar *option_name,
*/
typedef gboolean (*GOptionParseFunc) (GOptionContext *context,
GOptionGroup *group,
- gpointer user_data,
+ gpointer data,
GError **error);
/**
* GOptionErrorFunc:
* @context: The active #GOptionContext
* @group: The group to which the function belongs
- * @user_data: User data added to the #GOptionGroup containing the option when
- * it was created with g_option_group_new()
+ * @data: User data added to the #GOptionGroup containing the option when it
+ * was created with g_option_group_new()
* @error: The #GError containing details about the parse error
*
* The type of function to be used as callback when a parse error occurs.
*/
typedef void (*GOptionErrorFunc) (GOptionContext *context,
GOptionGroup *group,
- gpointer user_data,
+ gpointer data,
GError **error);
/**
diff --git a/glib/gsequence.c b/glib/gsequence.c
index 5c068f5ca..ead827d46 100644
--- a/glib/gsequence.c
+++ b/glib/gsequence.c
@@ -85,7 +85,7 @@
* GSequenceIterCompareFunc:
* @a: a #GSequenceIter
* @b: a #GSequenceIter
- * @user_data: user data
+ * @data: user data
*
* A #GSequenceIterCompareFunc is a function used to compare iterators.
* It must return zero if the iterators compare equal, a negative value
diff --git a/glib/gsequence.h b/glib/gsequence.h
index 464fe80fb..c1b340493 100644
--- a/glib/gsequence.h
+++ b/glib/gsequence.h
@@ -34,7 +34,7 @@ typedef struct _GSequenceNode GSequenceIter;
typedef gint (* GSequenceIterCompareFunc) (GSequenceIter *a,
GSequenceIter *b,
- gpointer user_data);
+ gpointer data);
/* GSequence */
diff --git a/glib/gspawn.h b/glib/gspawn.h
index 277c98cea..a3c4aca52 100644
--- a/glib/gspawn.h
+++ b/glib/gspawn.h
@@ -104,7 +104,7 @@ typedef enum
/**
* GSpawnChildSetupFunc:
- * @user_data: user data to pass to the function.
+ * @data: user data passed to the function.
*
* Specifies the type of the setup function passed to g_spawn_async(),
* g_spawn_sync() and g_spawn_async_with_pipes(), which can, in very
@@ -137,7 +137,7 @@ typedef enum
* and g_environ_unsetenv(), and then pass the complete environment
* list to the `g_spawn...` function.
*/
-typedef void (* GSpawnChildSetupFunc) (gpointer user_data);
+typedef void (* GSpawnChildSetupFunc) (gpointer data);
/**
* GSpawnFlags:
diff --git a/glib/gthread.c b/glib/gthread.c
index bc9b1c2b3..097b0820d 100644
--- a/glib/gthread.c
+++ b/glib/gthread.c
@@ -474,7 +474,7 @@
/**
* GThreadFunc:
- * @user_data: data passed to the thread
+ * @data: data passed to the thread
*
* Specifies the type of the @func functions passed to g_thread_new()
* or g_thread_try_new().
diff --git a/glib/gthread.h b/glib/gthread.h
index 5a8fc5fb1..e96632b91 100644
--- a/glib/gthread.h
+++ b/glib/gthread.h
@@ -46,7 +46,7 @@ typedef enum
G_THREAD_ERROR_AGAIN /* Resource temporarily unavailable */
} GThreadError;
-typedef gpointer (*GThreadFunc) (gpointer user_data);
+typedef gpointer (*GThreadFunc) (gpointer data);
typedef struct _GThread GThread;
diff --git a/glib/gtree.c b/glib/gtree.c
index df765b679..bbd609e5b 100644
--- a/glib/gtree.c
+++ b/glib/gtree.c
@@ -1197,7 +1197,7 @@ g_tree_foreach_node (GTree *tree,
* GTraverseFunc:
* @key: a key of a #GTree node
* @value: the value corresponding to the key
- * @user_data: user data passed to g_tree_traverse()
+ * @data: user data passed to g_tree_traverse()
*
* Specifies the type of function passed to g_tree_traverse(). It is
* passed the key and value of each node, together with the @user_data
diff --git a/glib/gtree.h b/glib/gtree.h
index baff68526..74ab9ce95 100644
--- a/glib/gtree.h
+++ b/glib/gtree.h
@@ -50,12 +50,12 @@ typedef struct _GTreeNode GTreeNode;
typedef gboolean (*GTraverseFunc) (gpointer key,
gpointer value,
- gpointer user_data);
+ gpointer data);
/**
* GTraverseNodeFunc:
* @node: a #GTreeNode
- * @user_data: user data passed to g_tree_foreach_node()
+ * @data: user data passed to g_tree_foreach_node()
*
* Specifies the type of function passed to g_tree_foreach_node(). It is
* passed each node, together with the @user_data parameter passed to
@@ -66,7 +66,7 @@ typedef gboolean (*GTraverseFunc) (gpointer key,
* Since: 2.68
*/
typedef gboolean (*GTraverseNodeFunc) (GTreeNode *node,
- gpointer user_data);
+ gpointer data);
/* Balanced binary trees
*/
diff --git a/glib/gtypes.h b/glib/gtypes.h
index 2312d5ae6..9d68f93a7 100644
--- a/glib/gtypes.h
+++ b/glib/gtypes.h
@@ -148,7 +148,7 @@ typedef void (*GHFunc) (gpointer key,
/**
* GCopyFunc:
* @src: (not nullable): A pointer to the data which should be copied
- * @user_data: Additional data
+ * @data: Additional data
*
* A function of this signature is used to copy the node data
* when doing a deep-copy of a tree.
@@ -158,7 +158,7 @@ typedef void (*GHFunc) (gpointer key,
* Since: 2.4
*/
typedef gpointer (*GCopyFunc) (gconstpointer src,
- gpointer user_data);
+ gpointer data);
/**
* GFreeFunc:
* @data: a data pointer
@@ -172,7 +172,7 @@ typedef void (*GFreeFunc) (gpointer data);
/**
* GTranslateFunc:
* @str: the untranslated string
- * @user_data: user data specified when installing the function, e.g.
+ * @data: user data specified when installing the function, e.g.
* in g_option_group_set_translate_func()
*
* The type of functions which are used to translate user-visible
@@ -182,7 +182,7 @@ typedef void (*GFreeFunc) (gpointer data);
* The returned string is owned by GLib and must not be freed.
*/
typedef const gchar * (*GTranslateFunc) (const gchar *str,
- gpointer user_data);
+ gpointer data);
/* Define some mathematical constants that aren't available
diff --git a/gobject/gsignal.h b/gobject/gsignal.h
index f37e67a36..312055b13 100644
--- a/gobject/gsignal.h
+++ b/gobject/gsignal.h
@@ -60,7 +60,7 @@ typedef GVaClosureMarshal GSignalCVaMarshaller;
* the instance on which the signal was emitted.
* @param_values: (array length=n_param_values): the instance on which
* the signal was emitted, followed by the parameters of the emission.
- * @user_data: user data associated with the hook.
+ * @data: user data associated with the hook.
*
* A simple function pointer to get invoked when the signal is emitted.
*
@@ -75,14 +75,14 @@ typedef GVaClosureMarshal GSignalCVaMarshaller;
typedef gboolean (*GSignalEmissionHook) (GSignalInvocationHint *ihint,
guint n_param_values,
const GValue *param_values,
- gpointer user_data);
+ gpointer data);
/**
* GSignalAccumulator:
* @ihint: Signal invocation hint, see #GSignalInvocationHint.
* @return_accu: Accumulator to collect callback return values in, this
* is the return value of the current signal emission.
* @handler_return: A #GValue holding the return value of the signal handler.
- * @user_data: Callback data that was specified when creating the signal.
+ * @data: Callback data that was specified when creating the signal.
*
* The signal accumulator is a special callback function that can be used
* to collect return values of the various callbacks that are called
@@ -103,7 +103,7 @@ typedef gboolean (*GSignalEmissionHook) (GSignalInvocationHint *ihint,
typedef gboolean (*GSignalAccumulator) (GSignalInvocationHint *ihint,
GValue *return_accu,
const GValue *handler_return,
- gpointer user_data);
+ gpointer data);
/* --- run, match and connect types --- */
diff --git a/gio/giotypes.h b/gio/giotypes.h
index f69766a38..82e091bef 100644
--- a/gio/giotypes.h
+++ b/gio/giotypes.h
@@ -263,7 +263,7 @@ typedef struct _GVolumeMonitor GVolumeMonitor;
* GAsyncReadyCallback:
* @source_object: (nullable): the object the asynchronous operation was started with.
* @res: a #GAsyncResult.
- * @user_data: user data passed to the callback.
+ * @data: user data passed to the callback.
*
* Type definition for a function that will be called back when an asynchronous
* operation within GIO has been completed. #GAsyncReadyCallback
@@ -280,13 +280,13 @@ typedef struct _GVolumeMonitor GVolumeMonitor;
**/
typedef void (*GAsyncReadyCallback) (GObject *source_object,
GAsyncResult *res,
- gpointer user_data);
+ gpointer data);
/**
* GFileProgressCallback:
* @current_num_bytes: the current number of bytes in the operation.
* @total_num_bytes: the total number of bytes in the operation.
- * @user_data: user data passed to the callback.
+ * @data: user data passed to the callback.
*
* When doing file operations that may take a while, such as moving
* a file or copying a file, a progress callback is used to pass how
@@ -294,13 +294,13 @@ typedef void (*GAsyncReadyCallback) (GObject *source_object,
**/
typedef void (*GFileProgressCallback) (goffset current_num_bytes,
goffset total_num_bytes,
- gpointer user_data);
+ gpointer data);
/**
* GFileReadMoreCallback:
* @file_contents: the data as currently read.
* @file_size: the size of the data currently read.
* @user_data: data passed to the callback.
*
* When loading the partial contents of a file with g_file_load_partial_contents_async(),
* it may become necessary to determine if any more data from the file should be loaded.
@@ -311,7 +311,7 @@ typedef void (*GFileProgressCallback) (goffset current_num_bytes,
**/
typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
goffset file_size,
- gpointer user_data);
+ gpointer callback_data);
/**
* GFileMeasureProgressCallback:
@@ -319,7 +319,7 @@ typedef gboolean (* GFileReadMoreCallback) (const char *file_contents,
* @current_size: the current cumulative size measurement
* @num_dirs: the number of directories visited so far
* @num_files: the number of non-directory files encountered
- * @user_data: the data passed to the original request for this callback
+ * @data: the data passed to the original request for this callback
*
* This callback type is used by g_file_measure_disk_usage() to make
* periodic progress reports when measuring the amount of disk spaced
@@ -355,13 +355,13 @@ typedef void (* GFileMeasureProgressCallback) (gboolean reporting,
guint64 current_size,
guint64 num_dirs,
guint64 num_files,
- gpointer user_data);
+ gpointer data);
/**
* GIOSchedulerJobFunc:
* @job: a #GIOSchedulerJob.
* @cancellable: optional #GCancellable object, %NULL to ignore.
- * @user_data: the data to pass to callback function
+ * @data: data passed to the callback function
*
* I/O Job function.
*
@@ -373,7 +373,7 @@ typedef void (* GFileMeasureProgressCallback) (gboolean reporting,
**/
typedef gboolean (*GIOSchedulerJobFunc) (GIOSchedulerJob *job,
GCancellable *cancellable,
- gpointer user_data);
+ gpointer data);
/**
* GSimpleAsyncThreadFunc:
@@ -392,7 +392,7 @@ typedef void (*GSimpleAsyncThreadFunc) (GSimpleAsyncResult *res,
* GSocketSourceFunc:
* @socket: the #GSocket
* @condition: the current condition at the source fired.
- * @user_data: data passed in by the user.
+ * @data: data passed in by the user.
*
* This is the function type of the callback used for the #GSource
* returned by g_socket_create_source().
@@ -403,13 +403,13 @@ typedef void (*GSimpleAsyncThreadFunc) (GSimpleAsyncResult *res,
*/
typedef gboolean (*GSocketSourceFunc) (GSocket *socket,
GIOCondition condition,
- gpointer user_data);
+ gpointer data);
/**
* GDatagramBasedSourceFunc:
* @datagram_based: the #GDatagramBased
* @condition: the current condition at the source fired
- * @user_data: data passed in by the user
+ * @data: data passed in by the user
*
* This is the function type of the callback used for the #GSource
* returned by g_datagram_based_create_source().
@@ -421,7 +421,7 @@ typedef gboolean (*GSocketSourceFunc) (GSocket *socket,
*/
typedef gboolean (*GDatagramBasedSourceFunc) (GDatagramBased *datagram_based,
GIOCondition condition,
- gpointer user_data);
+ gpointer data);
/**
* GInputVector:
@@ -573,7 +573,7 @@ typedef struct _GDBusNodeInfo GDBusNodeInfo;
/**
* GCancellableSourceFunc:
* @cancellable: the #GCancellable
- * @user_data: data passed in by the user.
+ * @data: data passed in by the user.
*
* This is the function type of the callback used for the #GSource
* returned by g_cancellable_source_new().
@@ -583,12 +583,12 @@ typedef struct _GDBusNodeInfo GDBusNodeInfo;
* Since: 2.28
*/
typedef gboolean (*GCancellableSourceFunc) (GCancellable *cancellable,
- gpointer user_data);
+ gpointer data);
/**
* GPollableSourceFunc:
* @pollable_stream: the #GPollableInputStream or #GPollableOutputStream
- * @user_data: data passed in by the user.
+ * @data: data passed in by the user.
*
* This is the function type of the callback used for the #GSource
* returned by g_pollable_input_stream_create_source() and
@@ -599,7 +599,7 @@ typedef gboolean (*GCancellableSourceFunc) (GCancellable *cancellable,
* Since: 2.28
*/
typedef gboolean (*GPollableSourceFunc) (GObject *pollable_stream,
- gpointer user_data);
+ gpointer data);
typedef struct _GDBusInterface GDBusInterface; /* Dummy typedef */
typedef struct _GDBusInterfaceSkeleton GDBusInterfaceSkeleton;
@@ -615,7 +615,7 @@ typedef struct _GDBusObjectManagerServer GDBusObjectManagerServer;
* @manager: A #GDBusObjectManagerClient.
* @object_path: The object path of the remote object.
* @interface_name: (nullable): The interface name of the remote object or %NULL if a #GDBusObjectProxy #GType is requested.
- * @user_data: User data.
+ * @data: data passed in by the user.
*
* Function signature for a function used to determine the #GType to
* use for an interface proxy (if @interface_name is not %NULL) or
@@ -634,7 +634,7 @@ typedef struct _GDBusObjectManagerServer GDBusObjectManagerServer;
typedef GType (*GDBusProxyTypeFunc) (GDBusObjectManagerClient *manager,
const gchar *object_path,
const gchar *interface_name,
- gpointer user_data);
+ gpointer data);
typedef struct _GTestDBus GTestDBus;
@@ -294,13 +294,13 @@ typedef void (*GAsyncReadyCallback) (GObject *source_object,
* @file_contents: the data as currently read.
* @file_size: the size of the data currently read.
- * @user_data: data passed to the callback.
+ * @callback_data: data passed to the callback.
*
* When loading the partial contents of a file with g_file_load_partial_contents_async(),
diff --git a/gobject/gclosure.h b/gobject/gclosure.h
index 4519e11be..3b139b062 100644
--- a/gobject/gclosure.h
+++ b/gobject/gclosure.h
@@ -112,7 +112,7 @@ typedef void (*GClosureNotify) (gpointer data,
* callback of @closure
* @invocation_hint: (nullable): the invocation hint given as the
* last argument to g_closure_invoke()
* @user_data: (nullable): additional data specified when
* registering the marshaller, see g_closure_set_marshal() and
* g_closure_set_meta_marshal()
*
@@ -123,7 +123,7 @@ typedef void (*GClosureMarshal) (GClosure *closure,
guint n_param_values,
const GValue *param_values,
gpointer invocation_hint,
- gpointer user_data);
+ gpointer marshal_data);
/**
* GVaClosureMarshal:
@@ -112,7 +112,7 @@ typedef void (*GClosureNotify) (gpointer data,
* @invocation_hint: (nullable): the invocation hint given as the
* last argument to g_closure_invoke()
- * @user_data: (nullable): additional data specified when
+ * @marshal_data: (nullable): additional data specified when
* registering the marshaller, see g_closure_set_marshal() and
* g_closure_set_meta_marshal()